rnalysis.filtering.CountFilter.normalize\_with\_scaling\_factors
================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: CountFilter.normalize_with_scaling_factors